<?php
namespace Helpers;

use Zeedhi\Framework\Session\Session;

class Environment {

	protected $session;

	const USER_INFO = 'USERINFO';
	const LAST_ACCESS = 'LASTACCESS';

	public function __construct(Session $session) {
		$this->session = $session;
	}

	public function startSession($userInfo = null) {
		$this->session->start();
		if (!empty($this->getUserInfo())){
			$this->session->migrate(true);
		}
		$this->setUserInfo($userInfo);
		if (!empty($userInfo)){
			$this->setLastAccess();
		}
	}

	public function setUserInfo($userInfo) {
		if(!empty($userInfo)) {
			$this->session->set(self::USER_INFO, json_encode($userInfo));
		}
	}

	private function setLastAccess() {
		$this->session->set(self::LAST_ACCESS, time());
	}

	public function getUserSessionParameter($parameterName) {
		$userParameters = $this->getUserInfo();
		return $userParameters[$parameterName];
	}

	public function hasUserSessionParameter($parameterName) {
	   return $this->getUserSessionParameter($parameterName) !== NULL;
	}

	public function getUserInfo() {
		return json_decode($this->session->get(self::USER_INFO), true);
	}

	private function getLastAccess() {
		return $this->session->get(self::LAST_ACCESS);
	}

	public function endSession(){
		$this->session->get(self::USER_INFO); //it should be removed when issue 99032 be solved
		return $this->session->destroy();
	}

	public function accessControl(){
		$lastAccess = $this->getLastAccess();
		if (time() - $lastAccess >= 28800){
			// renova acesso caso sessão do usuário tenha se expirado
			$this->session->migrate(true);
		}
		$this->setLastAccess();
	}
}